package ch.zhaw.projekt2.turnierverwaltung.main;

import ch.zhaw.projekt2.turnierverwaltung.*;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.layout.BorderPane;
import javafx.stage.Stage;

import java.util.logging.Logger;

/**
 * Class Main window is used to initialize the GUI Elements, Creating several Decorators and also getting the Factories
 * ready
 */
public class MainWindow extends Application {
    private final FileIO fileIO = new FileIO(System.getProperty("user.dir") +
            System.getProperty("file.separator") + "tournierverwaltung_angrynerds");
    private FactoryDecorator factoryDecorator;
    private TournamentDecorator tournamentDecorator = new TournamentDecorator(fileIO);
    private LanguageConfigurator languageConfigurator = new LanguageConfigurator();
    private Factory factory = new Factory(fileIO, tournamentDecorator, languageConfigurator);
    private static final Logger logger = Logger.getLogger(FileIO.class.getCanonicalName());

    /**
     * Start method used to initialize the main window and load it's needed component
     * Also sets the scene and set some values like min width and height
     *
     * @param primaryStage to be displayed
     */
    @Override
    public void start(Stage primaryStage) {
        logger.fine("Starting up the main window with the primary Stage");
        BorderPane pane = factory.loadMainWindow();
        factoryDecorator = new FactoryDecorator(fileIO, factory, pane);
        factory.loadAllViews(factoryDecorator, pane);
        tournamentDecorator.setFactoryDecorator(factoryDecorator);
        factoryDecorator.openTournamentList();
        languageConfigurator.translateGUI();

        Scene scene = new Scene(pane);
        primaryStage.setScene(scene);
        primaryStage.setMinHeight(600);
        primaryStage.setMinWidth(800);
        primaryStage.setMaximized(true);
        primaryStage.setResizable(true);
        primaryStage.setFullScreen(false);
        primaryStage.show();
    }

    /**
     * Method used to safely shut down the application
     */
    @Override
    public void stop() {
        try {
            super.stop();
            tournamentDecorator.closeApplication();
        } catch (Exception e) {
            logger.warning("Exception while closing application");
        }
    }
}
